@@ -54,7 +54,7 @@ using Banshee.Sources.Gui;
 
 namespace Nereid
 {
-    public class PlayerInterface : BaseClientWindow, IService, IDisposable, IHasSourceView
+    public class PlayerInterface : BaseClientWindow, IClientWindow, IDBusObjectName, IService, IDisposable, IHasSourceView
     {
         // Major Layout Components
         private VBox primary_vbox;
@@ -345,8 +345,17 @@ namespace Nereid
 
             view_container.Header.Visible = source.Properties.Contains ("Nereid.SourceContents.HeaderVisible") ?
                 source.Properties.Get<bool> ("Nereid.SourceContents.HeaderVisible") : true;
-
-            view_container.DiskUsageVisible = (source is IDiskUsageReporter);
+            
+            view_container.ClearFooter ();
+            Widget footer_widget = null;
+            
+            if (source.Properties.Contains ("Nereid.SourceContents.FooterWidget")) {
+                footer_widget = source.Properties.Get<Widget> ("Nereid.SourceContents.FooterWidget");
+            }
+            
+            if (footer_widget != null) {
+                view_container.SetFooter (footer_widget);
+            }
             
             UpdateSourceInformation ();
             view_container.SearchEntry.Ready = true;
@@ -433,16 +442,29 @@ namespace Nereid
 #region Gtk.Window Overrides
 
         private bool accel_group_active = true;
+
+        private void OnEntryFocusOutEvent (object o, FocusOutEventArgs args)
+        {
+            if (!accel_group_active) {
+                AddAccelGroup (ActionService.UIManager.AccelGroup);
+                accel_group_active = true;
+            }
+
+            (o as Widget).FocusOutEvent -= OnEntryFocusOutEvent;
+        }
         
         protected override bool OnKeyPressEvent (Gdk.EventKey evnt)
         {
             bool focus_search = false;
             
-            if (Focus is Entry && (GtkUtilities.NoImportantModifiersAreSet () && 
+            if (Focus is Gtk.Entry && (GtkUtilities.NoImportantModifiersAreSet () && 
                 evnt.Key != Gdk.Key.Control_L && evnt.Key != Gdk.Key.Control_R)) {
                 if (accel_group_active) {
                     RemoveAccelGroup (ActionService.UIManager.AccelGroup);
                     accel_group_active = false;
+
+                    // Reinstate the AccelGroup as soon as the focus leaves the entry
+                    Focus.FocusOutEvent += OnEntryFocusOutEvent;
                  }
             } else {
                 if (!accel_group_active) {
@@ -489,22 +511,6 @@ namespace Nereid
                 return;
             }
 
-            if (source is IDiskUsageReporter) {
-                IDiskUsageReporter reporter = source as IDiskUsageReporter;
-
-                double fraction = (double)reporter.BytesUsed / (double)reporter.BytesCapacity;
-
-                view_container.DiskUsageBar.Fraction = fraction;
-                view_container.DiskUsageBar.Text = String.Format(
-                    Catalog.GetString("{0} of {1}"),
-                    new Hyena.Query.FileSizeQueryValue (reporter.BytesUsed).ToUserQuery (),
-                    new Hyena.Query.FileSizeQueryValue (reporter.BytesCapacity).ToUserQuery ()
-                );
-
-                //string tooltip = dapSource.DiskUsageString + " (" + dapSource.DiskAvailableString + ")";
-                //toolTips.SetTip (dapDiskUsageBar, tooltip, tooltip);
-            }
-
             status_label.Text = source.GetStatusText ();
         }
 
@@ -528,6 +534,14 @@ namespace Nereid
 
 #endregion
 
+        IDBusExportable IDBusExportable.Parent {
+            get { return null; }
+        }
+        
+        string IDBusObjectName.ExportObjectName {
+            get { return "ClientWindow"; }
+        }
+
         string IService.ServiceName {
             get { return "NereidPlayerInterface"; }
         }
