@@ -31,6 +31,7 @@ using System;
 using System.Data;
 using System.Text;
 using System.Collections.Generic;
+using Mono.Unix;
 
 using Hyena;
 using Hyena.Data.Sqlite;
@@ -65,7 +66,7 @@ namespace Banshee.Collection.Database
         
         public override void UpdateSelectAllItem (long count)
         {
-            select_all_item.Title = String.Format ("All Albums ({0})", count);
+            select_all_item.Title = String.Format (Catalog.GetString ("All Albums ({0})"), count);
         }
     }
 }
