@@ -52,7 +52,7 @@ namespace Banshee.Database
         // NOTE: Whenever there is a change in ANY of the database schema,
         //       this version MUST be incremented and a migration method
         //       MUST be supplied to match the new version number
-        protected const int CURRENT_VERSION = 9;
+        protected const int CURRENT_VERSION = 11;
         protected const int CURRENT_METADATA_VERSION = 1;
         
 #region Migration Driver
@@ -381,6 +381,32 @@ namespace Banshee.Database
 
 #endregion
 
+#region Version 10
+
+        [DatabaseVersion (10)]
+        private bool Migrate_10 ()
+        {
+            // Clear these out for people who ran the pre-alpha podcast plugin
+            Execute ("DROP TABLE IF EXISTS PodcastEnclosures");
+            Execute ("DROP TABLE IF EXISTS PodcastItems");
+            Execute ("DROP TABLE IF EXISTS PodcastSyndications");
+            Execute ("ALTER TABLE CoreTracks ADD COLUMN ExternalID INTEGER");
+            return true;
+        }
+        
+#endregion
+
+#region Version 11
+        
+        [DatabaseVersion (11)]
+        private bool Migrate_11 ()
+        {
+            Execute("CREATE INDEX CoreTracksExternalIDIndex ON CoreTracks(PrimarySourceID, ExternalID)");
+            return true;
+        }
+        
+#endregion
+
 #pragma warning restore 0169
         
 #region Fresh database setup
@@ -428,6 +454,7 @@ namespace Banshee.Database
                     ArtistID            INTEGER,
                     AlbumID             INTEGER,
                     TagSetID            INTEGER,
+                    ExternalID          INTEGER,
                     
                     MusicBrainzID       TEXT,
 
@@ -462,6 +489,7 @@ namespace Banshee.Database
             ", (int)TrackMediaAttributes.Default, (int)StreamPlaybackError.None));
             Execute("CREATE INDEX CoreTracksPrimarySourceIndex ON CoreTracks(ArtistID, AlbumID, PrimarySourceID, Disc, TrackNumber, Uri)");
             Execute("CREATE INDEX CoreTracksAggregatesIndex ON CoreTracks(FileSize, Duration)");
+            Execute("CREATE INDEX CoreTracksExternalIDIndex ON CoreTracks(PrimarySourceID, ExternalID)");
             
             Execute(@"
                 CREATE TABLE CoreAlbums (
@@ -607,6 +635,7 @@ namespace Banshee.Database
                                 AND b.Name = Artist),
                         0,
                         0,
+                        0,
                         Uri,
                         0,
                         MimeType,
@@ -729,24 +758,26 @@ namespace Banshee.Database
                     DatabaseTrackInfo track = null;
                     try {
                         track = DatabaseTrackInfo.Provider.Load (reader);
-                        
-                        try {
-                            TagLib.File file = StreamTagger.ProcessUri (track.Uri);
-                            StreamTagger.TrackInfoMerge (track, file, true);
-                        } catch (Exception e) {
-                            Log.Warning (String.Format ("Failed to update metadata for {0}", track),
-                                e.GetType ().ToString (), false);
+
+                        if (track != null && track.Uri != null && track.Uri.IsFile) {
+                            try {
+                                TagLib.File file = StreamTagger.ProcessUri (track.Uri);
+                                StreamTagger.TrackInfoMerge (track, file, true);
+                            } catch (Exception e) {
+                                Log.Warning (String.Format ("Failed to update metadata for {0}", track),
+                                    e.GetType ().ToString (), false);
+                            }
+                            
+                            track.Save (false);
+                            track.Artist.Save ();
+                            track.Album.Save ();
+
+                            job.Status = String.Format ("{0} - {1}", track.DisplayArtistName, track.DisplayTrackTitle);
                         }
-                        
-                        track.Save (false);
-                        track.Artist.Save ();
-                        track.Album.Save ();
                     } catch (Exception e) {
                         Log.Warning (String.Format ("Failed to update metadata for {0}", track), e.ToString (), false);
-                        throw;
                     }
 
-                    job.Status = String.Format ("{0} - {1}", track.DisplayArtistName, track.DisplayTrackTitle);
                     job.Progress = (double)++count / (double)total;
                 }
             }
