@@ -120,6 +120,56 @@ namespace Banshee.Sources
         {
         }
 
+        protected bool NeedsReloadWhenFieldsChanged (Hyena.Query.QueryField [] fields)
+        {
+            if (fields == null) {
+                return true;
+            }
+
+            foreach (QueryField field in fields)
+                if (NeedsReloadWhenFieldChanged (field))
+                    return true;
+
+            return false;
+        }
+
+        private List<QueryField> query_fields;
+        private QueryNode last_query;
+        protected virtual bool NeedsReloadWhenFieldChanged (Hyena.Query.QueryField field)
+        {
+            if (field == null)
+                return true;
+
+            // If it's the artist or album name, then we care, since it affects the browser
+            if (field == Banshee.Query.BansheeQuery.ArtistField || field == Banshee.Query.BansheeQuery.AlbumField) {
+                return true;
+            }
+
+            ISortableColumn sort_column = (TrackModel is DatabaseTrackListModel)
+                ? (TrackModel as DatabaseTrackListModel).SortColumn : null;
+            // If it's the field we're sorting by, then yes, we care
+            // FIXME this Contains is very hacky, we should link the ISortableColumn to a field and/or a
+            // QueryOrder object
+            if (sort_column != null && field.Column.Contains (sort_column.SortKey)) {
+                return true;
+            }
+
+            // Make sure the query isn't dependent on this field
+            QueryNode query = (TrackModel is DatabaseTrackListModel)
+                ? (TrackModel as DatabaseTrackListModel).Query : null;
+            if (query != null) {
+                if (query != last_query) {
+                    query_fields = new List<QueryField> (query.GetFields ());
+                    last_query = query;
+                }
+
+                if (query_fields.Contains (field))
+                    return true;
+            }
+
+            return false;
+        }
+
 #region Public Properties
 
         public override int Count {
@@ -301,6 +351,13 @@ namespace Banshee.Sources
                 }
             }
             OnTracksChanged (BansheeQuery.RatingField);
+
+            // In case we updated the currently playing track
+            DatabaseTrackInfo track = ServiceManager.PlayerEngine.CurrentTrack as DatabaseTrackInfo;
+            if (track != null) {
+                track.Refresh ();
+                ServiceManager.PlayerEngine.TrackInfoUpdated ();
+            }
         }
 
         public override SourceMergeType SupportedMergeTypes {
@@ -412,23 +469,22 @@ namespace Banshee.Sources
 
         protected virtual void RemoveTrackRange (DatabaseTrackListModel model, RangeCollection.Range range)
         {
-            throw new NotImplementedException(); 
+            Log.ErrorFormat ("RemoveTrackRange not implemented by {0}", this);
         }
 
-
         protected virtual void DeleteTrackRange (DatabaseTrackListModel model, RangeCollection.Range range)
         {
-            throw new NotImplementedException(); 
+            Log.ErrorFormat ("DeleteTrackRange not implemented by {0}", this);
         }
 
         protected virtual void AddTrackRange (DatabaseTrackListModel model, RangeCollection.Range range)
         {
-            throw new NotImplementedException(); 
+            Log.ErrorFormat ("AddTrackRange not implemented by {0}", this);
         }
         
         protected virtual void AddTrack (DatabaseTrackInfo track)
         {
-            throw new NotImplementedException(); 
+            Log.ErrorFormat ("AddTrack not implemented by {0}", this);
         }
 
         protected virtual void RateTrackRange (DatabaseTrackListModel model, RangeCollection.Range range, int rating)
