@@ -47,23 +47,41 @@ namespace Banshee.Widgets
             
             this.seekRange = seekRange;
             this.seekRange.ValueChanged += OnSliderUpdated;
-            this.seekRange.DurationChanged += OnSliderUpdated;
-
+            
+        }
+        
+        protected override void OnRealized ()
+        {
+            base.OnRealized ();
+            
             BuildLayouts ();
             UpdateLabel ();
         }
         
         private void BuildLayouts ()
         {
+            if (layout != null) {
+                layout.Dispose ();
+            }
+            
             layout = new Pango.Layout (PangoContext);
             layout.FontDescription = PangoContext.FontDescription.Copy ();
             layout.Ellipsize = Pango.EllipsizeMode.None;
+        }
+        
+        protected override void OnSizeRequested (ref Gtk.Requisition requisition)
+        {
+            if (!IsRealized || layout == null) {
+                return;
+            }
             
-            layout.SetMarkup (String.Format (format_string, "W"));
+            EnsureStyle ();
             
             int width, height;
             layout.GetPixelSize (out width, out height);
-            HeightRequest = height;
+            
+            requisition.Width = width;
+            requisition.Height = height;
         }
         
         protected override bool OnExposeEvent (Gdk.EventExpose evnt)
@@ -89,12 +107,8 @@ namespace Banshee.Widgets
             int width, height;
             layout.GetPixelSize (out width, out height);
             
-            if (width > Allocation.Width) {
-                WidthRequest = width;
-            }
-            
             int x = Allocation.X + ((Allocation.Width - width) / 2);
-            int y = Allocation.Y + ((Allocation.Height - HeightRequest) / 2);
+            int y = Allocation.Y + ((Allocation.Height - height) / 2);
             Gdk.Rectangle rect = evnt.Area;
             
             if (render_bar) {
@@ -111,15 +125,18 @@ namespace Banshee.Widgets
             return true;
         }
         
+        private static string idle = Catalog.GetString ("Idle");
+        private static string contacting = Catalog.GetString ("Contacting...");
+
         private void UpdateLabel ()
         {
             if (is_buffering) {
                 double progress = buffering_progress * 100.0;
-                UpdateLabel (Catalog.GetString("Buffering") + ": " + progress.ToString ("0.0") + "%");
+                UpdateLabel (String.Format ("{0}: {1}%", Catalog.GetString("Buffering"), progress.ToString ("0.0")));
             } else if (is_contacting) {
-                UpdateLabel (Catalog.GetString ("Contacting..."));
+                UpdateLabel (contacting);
             } else if (seekRange.Value == 0 && seekRange.Duration == 0) {
-                UpdateLabel (Catalog.GetString ("Idle"));
+                UpdateLabel (idle);
             } else if (seekRange.Value == seekRange.Duration) {
                 UpdateLabel (FormatDuration ((long)seekRange.Value));
             } else {
@@ -131,7 +148,7 @@ namespace Banshee.Widgets
         private void UpdateLabel (string text)
         {
             layout.SetMarkup (String.Format (format_string, GLib.Markup.EscapeText (text)));
-            QueueDraw ();
+            QueueResize ();
         }
         
         private static string FormatDuration (long time)
@@ -181,6 +198,7 @@ namespace Banshee.Widgets
         public string FormatString {
             set { 
                 format_string = value;
+                BuildLayouts ();
                 UpdateLabel ();
             }
         }
