@@ -202,6 +202,7 @@ namespace Banshee.Lastfm.Radio
             Actions.UIManager.RemoveUi (actions_id);
             Actions.RemoveActionGroup (this);
             RestoreShuffleRepeat ();
+            ServiceManager.PlayerEngine.DisconnectEvent (OnPlayerEvent);
             base.Dispose ();
         }
 
@@ -268,7 +269,7 @@ namespace Banshee.Lastfm.Radio
         private void OnTrackVisitLastfm (object sender, EventArgs args)
         {
             Browser.Open (String.Format (
-                Catalog.GetString ("http://last.fm/music/{0}/{1}"),
+                Catalog.GetString ("http://last.fm/music/{0}/_/{1}"),
                 Encode (CurrentArtist), Encode (CurrentTrack)
             ));
         }
@@ -410,7 +411,7 @@ namespace Banshee.Lastfm.Radio
                 updating = true;
             }
 
-            bool have_user = (lastfm.Account.UserName != null);
+            bool have_user = (lastfm.Account != null && lastfm.Account.UserName != null);
             this["LastfmAddAction"].IsImportant = ServiceManager.PlaybackController.Source is LastfmSource;
             this["LastfmAddAction"].Sensitive = have_user;
             this["LastfmSortAction"].Sensitive = have_user;
